same_cl: Checks if two clusterings are the same up to permutation

View source: R/utils.R

same_clR Documentation

Checks if two clusterings are the same up to permutation

Description

Checks if two clusterings are the same up to permutation

Usage

same_cl(cl1, cl2, K)

Arguments

cl1

the first clustering

cl2

the second clustering

K

the number of clusters

Value

Returns TRUE if they are the same, and FALSE otherwise


yiqunchen/KmeansInference documentation built on June 4, 2022, 1:20 p.m.